/* drawing (DXF) to G-code (NGC) converter
 * Copyright 2013 Stefan Schuermans <stefan@schuermans.info>
 * Copyleft: CC-BY-SA http://creativecommons.org/licenses/by-sa/3.0/
 */

#ifndef LAYER_H
#define LAYER_H

#include <list>

#include "gcode.h"
#include "path.h"
#include "settings.h"

/// layer of drawing
class Layer {
public:
  typedef std::list<Path> Paths; ///< type for paths in layer

  /**
   * @brief add a new empty path to the layer
   * @return reference to new empty path
   */
  Path & addPath();

  /**
   * @brief improve paths
   * @param[in] eqDist maximum distance of two points to be considered equal
   */
  void improvePaths(double eqDist);

  /**
   * @brief convert layer to G-code
   * @param[in] settings G-code creation settings
   * @param[in,out] gcode new G-code is appended to existing G-code
   */
  void toGCode(const Settings &settings, GCode &gcode) const;

  Paths mPaths; ///< paths in layer
};

#endif // #ifndef LAYER_H

