/* drawing (DXF) to G-code (NGC) converter
 * Copyright 2013 Stefan Schuermans <stefan@schuermans.info>
 * Copyleft: CC-BY-SA http://creativecommons.org/licenses/by-sa/3.0/
 */

#ifndef SETTINGS_H
#define SETTINGS_H

/// settings for creation of G-code
class Settings {
public:
  /// layer mode
  enum LayerMode {
    LevelByLevel, ///< cut all paths at the each level (z), then next level
    PathByPath,   ///< cut each path all the way down, then next path
  };

  /// set some reasonable/safe default settings
  Settings();

  double    base_z;        ///< z coordinate of workpiece surface
  double    cut_z;         ///< z coordinate of maximum cutting
  double    cut_z_step;    ///< z coordinate delta to cut in one step, > 0.0
  double    dwell_time;    ///< dwell time before cutting each path (in sec)
  double    feed_drill;    ///< feed rate for drilling
  double    feed_mill;     ///< feed rate for milling
  LayerMode layer_mode;    ///< layer cutting mode (see LayerMode)
  double    move_z;        ///< z coordinate for moving
  double    offset_x;      ///< offset to add to X coordinate
  double    offset_y;      ///< offset to add to Y coordinate
  double    precision;     ///< precision, >= 1.0e-8 , <= 1.0
  double    rotation_z;    ///< rotation around Z axis in degrees
  double    tool_diameter; ///< diameter of cutting tool, >= 0.0
};

#endif // #ifndef SETTINGS_H

